@@ -50,6 +50,11 @@ class CreateSegmentForm(forms.SelfHandlingForm):
     description = forms.CharField(
         label=_("Description"), widget=forms.Textarea(
             attrs={'rows': 4}), required=False)
+    is_enabled = forms.BooleanField(
+        label=_("Enabled"),
+        required=False,
+        initial=True,
+    )
 
     def __init__(self, *args, **kwargs):
         super(CreateSegmentForm, self).__init__(*args, **kwargs)
@@ -91,12 +96,19 @@ class UpdateForm(forms.SelfHandlingForm):
             attrs={'width': "100%", 'cols': "80", 'rows': "5", }),
         required=False
     )
+    is_enabled = forms.BooleanField(
+        label=_("Enabled"),
+        required=False,
+    )
 
     def handle(self, request, data):
         try:
-            fields_to_update = {'name': data['name'],
-                                'recovery_method': data['recovery_method'],
-                                'description': data['description']}
+            fields_to_update = {
+                'name': data['name'],
+                'recovery_method': data['recovery_method'],
+                'description': data['description'],
+                'is_enabled': data['is_enabled'],
+            }
             api.segment_update(request, data['uuid'], fields_to_update)
             msg = _('Successfully updated segment.')
             messages.success(request, msg)
@@ -148,22 +160,19 @@ class AddHostForm(forms.SelfHandlingForm):
     def __init__(self, *args, **kwargs):
         super(AddHostForm, self).__init__(*args, **kwargs)
 
-        # Populate candidate name choices
-        available_host_list = kwargs.get('initial', {}).get(
-            "available_host_list", [])
-        host_candidate_list = []
-        # NOTE(pas-ha) available_host_list contains
-        # novaclient v2 Service objects
-        for service in available_host_list:
-            host_candidate_list.append(
-                (service.host, '%(name)s (%(id)s)'
-                 % {"name": service.host,
-                    "id": service.id}))
-        if host_candidate_list:
-            host_candidate_list.insert(0, ("", _("Select a host")))
+        # Populate hypervisor name choices
+        hypervisor_list = kwargs.get('initial', {}).get("hypervisor_list", [])
+        hypervisor_name_list = []
+        for hypervisor in hypervisor_list:
+            hypervisor_name_list.append(
+                (hypervisor.hypervisor_hostname, '%(name)s (%(id)s)'
+                 % {"name": hypervisor.hypervisor_hostname,
+                    "id": hypervisor.id}))
+        if hypervisor_name_list:
+            hypervisor_name_list.insert(0, ("", _("Select a host")))
         else:
-            host_candidate_list.insert(0, ("", _("No host available")))
-        self.fields['name'].choices = host_candidate_list
+            hypervisor_name_list.insert(0, ("", _("No host available")))
+        self.fields['name'].choices = hypervisor_name_list
 
     def handle(self, request, data):
         try:
